#!/usr/bin/env node
'use strict';

var yargs = require('yargs');
var path = require('path');

var _require = require('./../lib'),
    modelToArray = _require.modelToArray,
    sendToJson = _require.sendToJson,
    clearFile = _require.clearFile,
    makeRelationship = _require.makeRelationship;

var pkg = require('./../package.json');

var argv = yargs.config('config').usage('$0 [options] <source>').options({
  json: {
    alias: 'j',
    description: 'Set json path',
    default: 'db.json'
  },
  inserts: {
    alias: 'i',
    description: 'Set the number of random inserts',
    default: 5
  },
  clean: {
    alias: 'c',
    description: 'Clean json before generating'
  },
  replace: {
    alias: 'r',
    description: 'Replace objects already generated from model.'
  }
}).boolean('clean').boolean('replace').help('help').alias('help', 'h').version(pkg.version).alias('version', 'v').example('$0 user.model.ts --json=db.json --inserts=5 --clean', '').example('$0 user.model.ts --json=db.json --inserts=3', '').epilog('https://github.com/angular-labs/typescript-model-to-json-server').require(1, 'Missing <model> argument').argv;

var jsonPath = path.join(process.cwd(), '' + argv.json);
var inserts = Number(argv.inserts);
var replace = argv.replace;
var clean = argv.clean;

if (clean) clearFile(jsonPath);

for (var i = 0; i < argv._.length; i++) {
  var modelPath = path.join(process.cwd(), '' + argv._[i]);

  var attrs = modelToArray(modelPath);

  sendToJson(attrs, inserts, replace, jsonPath, argv._[i]);
}

makeRelationship(jsonPath);