'use strict';

var fs = require('fs');
var _ = require('lodash');
var pluralize = require('pluralize');

function writeJson(jsonPath, data) {
  var file = void 0;

  try {
    file = fs.writeFileSync(jsonPath, JSON.stringify(data), { encoding: 'utf-8' });
  } catch (err) {
    file = false;
  }

  return file;
}

function setRelation(data, result, item, model, index) {
  var s_model = pluralize.singular(model);
  if (data[item] === undefined || data[item] === null) {
    result[model][index][item] = null;
  } else {
    if (typeof result[model][index][item] === 'string') {
      result[model][index][item] = [];
    }
    for (var i = 0, n = 0; i < data[item].length; i++) {
      if (typeof result[item][i][s_model] === 'string') {
        delete data[item][i][s_model];
        result[model][index][item].push(JSON.parse(JSON.stringify(data[item][i])));
        delete data[model][index][item];
        result[item][i][s_model] = JSON.parse(JSON.stringify(data[model][index]));
        n += 1;
      }

      if (n > 1) break;
    }
  }
  return result;
}

module.exports = {
  modelToArray: function modelToArray(modelPath) {
    var data = void 0;
    try {
      data = fs.readFileSync(modelPath, { encoding: 'utf-8' });
    } catch (err) {
      throw err;
    }
    var flag = -1;
    var attrs = [];
    var index = 0;
    var lines = data.split('\n');
    var start = false;
    attrs[index] = {};
    attrs[index].name = '';
    attrs[index].type = '';

    _.forEach(lines, function (line) {
      if (line.includes('interface')) {
        start = true;
      }
      if (start) {
        _.forEach(line, function (item) {
          if (item !== '' && item !== '\n' && item !== undefined && item !== ':' && item !== '}' && item !== ';' && item !== ' ') {
            if (flag === 0) attrs[index].name += item;else if (flag === 1) attrs[index].type += item;
          }
          switch (item) {
            case '{':
              flag = 0;
              break;
            case ':':
              flag = 1;
              break;
            case ';':
              flag = 0;
              index += 1;
              attrs[index] = {};
              attrs[index].name = '';
              attrs[index].type = '';
              break;
            case '}':
              flag = 2;
              break;
          }
        });
      }
    });
    attrs.splice(index, 1);

    return attrs;
  },

  sendToJson: function sendToJson(attrs, inserts, replace, jsonPath, modelName) {
    var data = [];
    var value = null;

    var _loop = function _loop(i) {
      data[i] = {};
      _.forEach(attrs, function (item) {
        value = null;
        if (item.type === 'string') {
          value = item.name.substr(0, 5) + '-' + Math.random().toString(36).substr(2, 5);
        } else if (item.type === 'number') {
          value = Math.floor(Math.random() * (1000 - 1) + 1);
        } else if (item.type === 'Date') {
          value = Date.now().toString();
        } else {
          value = 'relation-' + item.type; // preparing to potential relationship
        }
        data[i][item.name] = value;
      });
    };

    for (var i = 0; i < inserts; i++) {
      _loop(i);
    }

    // get name of root object
    var name = modelName.split('/');
    var result = {};
    var file = void 0;
    name = name[name.length - 1].split('.')[0];

    if (pluralize.isSingular(name)) name = pluralize.plural(name);

    try {
      file = fs.readFileSync(jsonPath, { encoding: 'utf-8' });
    } catch (err) {
      file = false;
    }
    if (file) result = JSON.parse(file);

    if (!result[name]) result[name] = [];

    if (replace) {
      result[name] = data;
    } else {
      result[name].push.apply(result[name], data);
    }
    writeJson(jsonPath, result);
  },

  clearFile: function clearFile(jsonPath) {
    fs.writeFile(jsonPath, '', 'utf-8', function (err) {
      if (err) throw err;
    });
  },

  makeRelationship: function makeRelationship(jsonPath) {
    var data = void 0,
        result = void 0,
        itemName = void 0,
        aux = void 0;
    try {
      data = fs.readFileSync(jsonPath, { encoding: 'utf-8' });
      data = JSON.parse(data);
    } catch (err) {
      throw err;
    }

    result = JSON.parse(JSON.stringify(data));
    for (var model in data) {
      if (data.hasOwnProperty(model)) {
        for (var i = 0; i < data[model].length; i++) {
          for (var attr in data[model][i]) {
            if (data[model][i].hasOwnProperty(attr) && typeof data[model][i][attr] == 'string') {
              aux = data[model][i][attr].split('-');
              if (aux[0] == 'relation') {
                if (aux[1].slice(-2) == '[]') {
                  itemName = aux[1].slice(0, -2).toLowerCase();
                  if (pluralize.isSingular(itemName)) itemName = pluralize.plural(itemName);
                  result = setRelation(data, result, itemName, model, i);
                } else {
                  itemName = aux[1].toLowerCase();
                  if (pluralize.isSingular(itemName)) itemName = pluralize.plural(itemName);
                  result = setRelation(data, result, model, itemName, i);
                }
              }
            }
          }
        }
      }
    }

    writeJson(jsonPath, result);
  }
};